@@ -4,7 +4,7 @@ import os
 def get_test_data_resource(filename: str) -> str:
     root = os.path.dirname(os.path.abspath(__file__))
     with open(
-        os.path.join(root, "../../statsig-lib/tests/data", filename), "r"
+        os.path.join(root, "../../statsig-rust/tests/data", filename), "r"
     ) as file:
         file_content = file.read()
 
