@@ -3,11 +3,13 @@ pub mod dynamic_string;
 pub mod dynamic_value;
 pub mod evaluation_details;
 pub mod evaluation_types;
+pub mod evaluation_types_initialize_v2;
 pub mod evaluation_types_v2;
 pub mod evaluator;
 pub mod evaluator_context;
 pub mod evaluator_result;
 pub mod evaluator_value;
+pub mod secondary_exposure_key;
 pub mod user_agent_parsing;
 
 pub(crate) mod cmab_evaluator;
